@@ -23,6 +23,11 @@
 #include <glib.h>
 #include <time.h>
 
+#ifdef HAVE_LIBIPTCDATA
+#include <libiptcdata/iptc-data.h>
+#include <libiptcdata/iptc-jpeg.h>
+#endif /* HAVE_LIBIPTCDATA */
+
 #ifndef COMMENTS_H
 #define COMMENTS_H
 
@@ -38,10 +43,16 @@ typedef struct {
 				     * gthumb for GNOME 1.x saved text in 
 				     * locale format, gthumb for
 				     * GNOME 2.x saves in utf8 format. */
+
+#ifdef HAVE_LIBIPTCDATA
+	IptcData  *iptc_data;
+#endif /* HAVE_LIBIPTCDATA */
+
+	gboolean   changed;
 } CommentData;
 
 
-CommentData *  comment_data_new                    ();
+CommentData *  comment_data_new                    (void);
 
 void           comment_data_free                   (CommentData *data);
 
@@ -59,6 +70,7 @@ void           comment_data_add_keyword            (CommentData *data,
 
 gboolean       comment_data_is_void                (CommentData *data);
 
+gboolean       comment_text_is_void                (CommentData *data);
 
 /* -- */
 
@@ -86,7 +98,8 @@ void           comments_remove_old_comments_async  (const char  *dir,
 						    gboolean     recursive, 
 						    gboolean     clear_all);
 
-CommentData *  comments_load_comment               (const char  *filename);
+CommentData *  comments_load_comment               (const char  *filename,
+						    gboolean     try_embedded);
 
 void           comments_save_comment               (const char  *filename,
 						    CommentData *data);
