@@ -644,11 +644,13 @@ ensure_local_theme_dir_exists (void)
 	char *theme_dir;
 
 	theme_dir = g_build_path (G_DIR_SEPARATOR_S,
-				  g_get_home_dir (),
+				  get_home_uri (),
 				  ".gnome2",
 				  "gthumb/albumthemes",
 				  NULL);
-	mkdir (theme_dir, 0700);
+
+	dir_make (theme_dir, 0700);
+
 	g_free (theme_dir);
 }
 
@@ -659,19 +661,22 @@ install_theme__ok_cb (GtkDialog  *file_sel,
 		      gpointer    data)
 {
 	ThemeDialogData  *tdata;
-	char             *theme_archive;
+	char             *theme_archive, *e_theme_archive;
 	char             *command_line = NULL;
 	GError           *err = NULL;
 
 	tdata = g_object_get_data (G_OBJECT (file_sel), "theme_dialog_data");
-	theme_archive = g_strdup (gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (file_sel)));
+	e_theme_archive = g_strdup (gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (file_sel)));
 	gtk_widget_destroy (GTK_WIDGET (file_sel));
 
-	if (theme_archive == NULL)
+	if (e_theme_archive == NULL)
 		return;
 
 	/**/
 
+	theme_archive = gnome_vfs_unescape_string (e_theme_archive, "");
+	g_free (e_theme_archive);
+
 	ensure_local_theme_dir_exists ();
             
 	if (file_extension_is (theme_archive, ".tar.gz")
@@ -686,7 +691,7 @@ install_theme__ok_cb (GtkDialog  *file_sel,
 						g_get_home_dir (),
 						"/.gnome2/gthumb/albumthemes",
 						theme_archive);
-	
+
 	if ((command_line != NULL) 
 	    && ! g_spawn_command_line_sync (command_line, NULL, NULL, NULL, &err)
 	    && (err != NULL))
@@ -719,19 +724,16 @@ theme_dialog__install_theme_clicked (GtkWidget       *widget,
 				     ThemeDialogData *tdata)
 {
 	GtkWidget *file_sel;
-	char      *home;
 
 	file_sel = gtk_file_chooser_dialog_new (_("Select Album Theme"), NULL,
-						GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
+						GTK_FILE_CHOOSER_ACTION_OPEN,
 						GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 						GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
 						NULL);
 	gtk_window_set_modal (GTK_WINDOW (file_sel), TRUE);
 	g_object_set_data (G_OBJECT (file_sel), "theme_dialog_data", tdata);
 
-	home = g_strconcat (g_get_home_dir (), "/", NULL);
-	gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (file_sel), home);
-	g_free (home);
+	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (file_sel), g_get_home_dir ());
 
 	g_signal_connect (GTK_DIALOG (file_sel),
 			  "response",
